@@ -34,19 +34,41 @@
 //
 // provides a function that sends AJAX requests to the App::MFILE::WWW server
 // (which forwards them to the REST server) and takes action based on the
-// result.
+// HTTP response received.
 //
 // The 'ajax' function takes three arguments:
 // - MFILE AJAX Object (an object)
-// - success callback (a function, can be null or undefined)
-// - failure callback (a function, can be null or undefined)
+// - success callback 
+// - failure callback
 //
-// The MFILE AJAX Object looks like this:
+// The success and failure callbacks can be null or undefined, in which case App::MFILE::WWW will
+// just display the status text in the #result div (i.e., the line at the bottom of the frame).
+// If your AJAX calls needs any other handling than this, you need to provide at least a success
+// callback.
+//
+// In all cases except login/logout, the MFILE AJAX Object looks like this:
 // {
-//     "method": any HTTP method accepted by the REST server, or 'LOGIN'
-//     "path": valid path to REST server resource, or 'login'/'logout'
-//     "body": content body to be sent to REST server, or login credentials
+//     "method": any HTTP method accepted by the REST server
+//     "path": valid path to REST server resource
+//     "body": content body to be sent to REST server (can be null)
 // }
+//
+// MFILE AJAX Object for _login_ to REST server:
+// {
+//     "method": "LOGIN",
+//     "path": "login",
+//     "body": { "nam": $USERNAME, "pas": $PASSWORD }
+// }
+//
+// MFILE AJAX Object for _logout_ from REST server:
+// {
+//     "method": "LOGIN",
+//     "path": "logout",
+//     "body": null
+// }
+//
+// For details on how AJAX calls are handled, see lib/App/MFILE/WWW/Resource.pm
+//
 "use strict";
 
 define ([
@@ -61,7 +83,8 @@ define ([
             // mfao is 'MFILE AJAX Object'
             // scb is 'Success Call Back' 
             // fcb is 'Failure Call Back' 
-            $('#result').html('');
+            $('#result').css('text-align', 'center');
+            $('#result').html('* * * Communicating with REST server * * *');
             console.log("MFILE.lib.AJAX", mfao);
             $.ajax({
                 'url': '/',
@@ -71,7 +94,6 @@ define ([
                 'contentType': 'application/json'
             })
             .done(function (data) {
-                console.log("AJAX call returned ", data);
                 if (data.level === 'OK') {
                     console.log("AJAX call success:", data);
                     if (scb) {
