@@ -52,25 +52,29 @@ define([
                 $('#mainarea').html(html.logout());
                 setTimeout(function () { location.reload(); }, 1500);
             },
-            // if in standalone mode (i.e. if connectToRestServer is false),
-            // 'logout' means just reload the page
-            logout = cf('connectToRestServer') === 'false'
-                ? function () { displayLogoutMessage(); }
-                : function () {
-                    var rest = {
-                            method: 'LOGIN',
-                            path: 'logout',
-                            body: null
-                        },
-                        // success callback
-                        sc = function (status) {
-                            $('#result').html('Logout successful: ' + status.text);
-                            displayLogoutMessage();
-                        },
-                        // failure callback
-                        fc = null;
-                    ajax(rest, sc, fc);
-                };
+            logout;
+
+        // if in standalone mode (i.e. if connectToRestServer is false),
+        // 'logout' means just reload the page
+        if (cf('connectToRestServer')) {
+            logout = function () {
+                var rest = {
+                        method: 'LOGIN',
+                        path: 'logout',
+                        body: null
+                    },
+                    // success callback
+                    sc = function (status) {
+                        $('#result').html('Logout successful: ' + status.text);
+                        displayLogoutMessage();
+                    },
+                    // failure callback
+                    fc = null;
+                ajax(rest, sc, fc);
+            };
+        } else {
+            logout = function () { displayLogoutMessage(); };
+        }
         logout();
     }
 });
